# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class NamespaceDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'int',
        'registration_type': 'NamespaceRegistrationTypeEnum',
        'depth': 'int',
        'level0': 'str',
        'level1': 'str',
        'level2': 'str',
        'alias': 'AliasDTO',
        'parent_id': 'str',
        'owner_address': 'str',
        'start_height': 'str',
        'end_height': 'str'
    }

    attribute_map = {
        'version': 'version',
        'registration_type': 'registrationType',
        'depth': 'depth',
        'level0': 'level0',
        'level1': 'level1',
        'level2': 'level2',
        'alias': 'alias',
        'parent_id': 'parentId',
        'owner_address': 'ownerAddress',
        'start_height': 'startHeight',
        'end_height': 'endHeight'
    }

    def __init__(self, version=None, registration_type=None, depth=None, level0=None, level1=None, level2=None, alias=None, parent_id=None, owner_address=None, start_height=None, end_height=None, local_vars_configuration=None):  # noqa: E501
        """NamespaceDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._registration_type = None
        self._depth = None
        self._level0 = None
        self._level1 = None
        self._level2 = None
        self._alias = None
        self._parent_id = None
        self._owner_address = None
        self._start_height = None
        self._end_height = None
        self.discriminator = None

        self.version = version
        self.registration_type = registration_type
        self.depth = depth
        self.level0 = level0
        if level1 is not None:
            self.level1 = level1
        if level2 is not None:
            self.level2 = level2
        self.alias = alias
        self.parent_id = parent_id
        self.owner_address = owner_address
        self.start_height = start_height
        self.end_height = end_height

    @property
    def version(self):
        """Gets the version of this NamespaceDTO.  # noqa: E501

        The version of the state  # noqa: E501

        :return: The version of this NamespaceDTO.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this NamespaceDTO.

        The version of the state  # noqa: E501

        :param version: The version of this NamespaceDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def registration_type(self):
        """Gets the registration_type of this NamespaceDTO.  # noqa: E501


        :return: The registration_type of this NamespaceDTO.  # noqa: E501
        :rtype: NamespaceRegistrationTypeEnum
        """
        return self._registration_type

    @registration_type.setter
    def registration_type(self, registration_type):
        """Sets the registration_type of this NamespaceDTO.


        :param registration_type: The registration_type of this NamespaceDTO.  # noqa: E501
        :type: NamespaceRegistrationTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and registration_type is None:  # noqa: E501
            raise ValueError("Invalid value for `registration_type`, must not be `None`")  # noqa: E501

        self._registration_type = registration_type

    @property
    def depth(self):
        """Gets the depth of this NamespaceDTO.  # noqa: E501

        Level of the namespace.  # noqa: E501

        :return: The depth of this NamespaceDTO.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this NamespaceDTO.

        Level of the namespace.  # noqa: E501

        :param depth: The depth of this NamespaceDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and depth is None:  # noqa: E501
            raise ValueError("Invalid value for `depth`, must not be `None`")  # noqa: E501

        self._depth = depth

    @property
    def level0(self):
        """Gets the level0 of this NamespaceDTO.  # noqa: E501

        Namespace identifier.  # noqa: E501

        :return: The level0 of this NamespaceDTO.  # noqa: E501
        :rtype: str
        """
        return self._level0

    @level0.setter
    def level0(self, level0):
        """Sets the level0 of this NamespaceDTO.

        Namespace identifier.  # noqa: E501

        :param level0: The level0 of this NamespaceDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and level0 is None:  # noqa: E501
            raise ValueError("Invalid value for `level0`, must not be `None`")  # noqa: E501

        self._level0 = level0

    @property
    def level1(self):
        """Gets the level1 of this NamespaceDTO.  # noqa: E501

        Namespace identifier.  # noqa: E501

        :return: The level1 of this NamespaceDTO.  # noqa: E501
        :rtype: str
        """
        return self._level1

    @level1.setter
    def level1(self, level1):
        """Sets the level1 of this NamespaceDTO.

        Namespace identifier.  # noqa: E501

        :param level1: The level1 of this NamespaceDTO.  # noqa: E501
        :type: str
        """

        self._level1 = level1

    @property
    def level2(self):
        """Gets the level2 of this NamespaceDTO.  # noqa: E501

        Namespace identifier.  # noqa: E501

        :return: The level2 of this NamespaceDTO.  # noqa: E501
        :rtype: str
        """
        return self._level2

    @level2.setter
    def level2(self, level2):
        """Sets the level2 of this NamespaceDTO.

        Namespace identifier.  # noqa: E501

        :param level2: The level2 of this NamespaceDTO.  # noqa: E501
        :type: str
        """

        self._level2 = level2

    @property
    def alias(self):
        """Gets the alias of this NamespaceDTO.  # noqa: E501


        :return: The alias of this NamespaceDTO.  # noqa: E501
        :rtype: AliasDTO
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this NamespaceDTO.


        :param alias: The alias of this NamespaceDTO.  # noqa: E501
        :type: AliasDTO
        """
        if self.local_vars_configuration.client_side_validation and alias is None:  # noqa: E501
            raise ValueError("Invalid value for `alias`, must not be `None`")  # noqa: E501

        self._alias = alias

    @property
    def parent_id(self):
        """Gets the parent_id of this NamespaceDTO.  # noqa: E501

        Namespace identifier.  # noqa: E501

        :return: The parent_id of this NamespaceDTO.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this NamespaceDTO.

        Namespace identifier.  # noqa: E501

        :param parent_id: The parent_id of this NamespaceDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and parent_id is None:  # noqa: E501
            raise ValueError("Invalid value for `parent_id`, must not be `None`")  # noqa: E501

        self._parent_id = parent_id

    @property
    def owner_address(self):
        """Gets the owner_address of this NamespaceDTO.  # noqa: E501

        Address expressed in hexadecimal base.  # noqa: E501

        :return: The owner_address of this NamespaceDTO.  # noqa: E501
        :rtype: str
        """
        return self._owner_address

    @owner_address.setter
    def owner_address(self, owner_address):
        """Sets the owner_address of this NamespaceDTO.

        Address expressed in hexadecimal base.  # noqa: E501

        :param owner_address: The owner_address of this NamespaceDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and owner_address is None:  # noqa: E501
            raise ValueError("Invalid value for `owner_address`, must not be `None`")  # noqa: E501

        self._owner_address = owner_address

    @property
    def start_height(self):
        """Gets the start_height of this NamespaceDTO.  # noqa: E501

        Height of the blockchain.  # noqa: E501

        :return: The start_height of this NamespaceDTO.  # noqa: E501
        :rtype: str
        """
        return self._start_height

    @start_height.setter
    def start_height(self, start_height):
        """Sets the start_height of this NamespaceDTO.

        Height of the blockchain.  # noqa: E501

        :param start_height: The start_height of this NamespaceDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and start_height is None:  # noqa: E501
            raise ValueError("Invalid value for `start_height`, must not be `None`")  # noqa: E501

        self._start_height = start_height

    @property
    def end_height(self):
        """Gets the end_height of this NamespaceDTO.  # noqa: E501

        Height of the blockchain.  # noqa: E501

        :return: The end_height of this NamespaceDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_height

    @end_height.setter
    def end_height(self, end_height):
        """Sets the end_height of this NamespaceDTO.

        Height of the blockchain.  # noqa: E501

        :param end_height: The end_height of this NamespaceDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and end_height is None:  # noqa: E501
            raise ValueError("Invalid value for `end_height`, must not be `None`")  # noqa: E501

        self._end_height = end_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NamespaceDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NamespaceDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from symbol_openapi_client.api_client import ApiClient
from symbol_openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SecretLockRoutesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_secret_lock(self, composite_hash, **kwargs):  # noqa: E501
        """Get secret lock information  # noqa: E501

        Gets the hash lock for a given composite hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_secret_lock(composite_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str composite_hash: Filter by composite hash. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecretLockInfoDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_secret_lock_with_http_info(composite_hash, **kwargs)  # noqa: E501

    def get_secret_lock_with_http_info(self, composite_hash, **kwargs):  # noqa: E501
        """Get secret lock information  # noqa: E501

        Gets the hash lock for a given composite hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_secret_lock_with_http_info(composite_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str composite_hash: Filter by composite hash. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecretLockInfoDTO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'composite_hash'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_secret_lock" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'composite_hash' is set
        if self.api_client.client_side_validation and ('composite_hash' not in local_var_params or  # noqa: E501
                                                        local_var_params['composite_hash'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `composite_hash` when calling `get_secret_lock`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'composite_hash' in local_var_params:
            path_params['compositeHash'] = local_var_params['composite_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/lock/secret/{compositeHash}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecretLockInfoDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_secret_lock_merkle(self, composite_hash, **kwargs):  # noqa: E501
        """Get secret lock merkle information  # noqa: E501

        Gets the hash lock merkle for a given composite hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_secret_lock_merkle(composite_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str composite_hash: Filter by composite hash. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MerkleStateInfoDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_secret_lock_merkle_with_http_info(composite_hash, **kwargs)  # noqa: E501

    def get_secret_lock_merkle_with_http_info(self, composite_hash, **kwargs):  # noqa: E501
        """Get secret lock merkle information  # noqa: E501

        Gets the hash lock merkle for a given composite hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_secret_lock_merkle_with_http_info(composite_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str composite_hash: Filter by composite hash. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MerkleStateInfoDTO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'composite_hash'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_secret_lock_merkle" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'composite_hash' is set
        if self.api_client.client_side_validation and ('composite_hash' not in local_var_params or  # noqa: E501
                                                        local_var_params['composite_hash'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `composite_hash` when calling `get_secret_lock_merkle`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'composite_hash' in local_var_params:
            path_params['compositeHash'] = local_var_params['composite_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/lock/secret/{compositeHash}/merkle', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MerkleStateInfoDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_secret_lock(self, **kwargs):  # noqa: E501
        """Search secret lock entries  # noqa: E501

        Returns an array of secret locks.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_secret_lock(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Filter by address involved in the transaction.  An account's address is considered to be involved in the transaction when the account is the sender, recipient, or it is required to cosign the transaction. This filter cannot be combined with ``recipientAddress`` and ``signerPublicKey`` query params. 
        :param str secret: Filter by secret.
        :param int page_size: Select the number of entries to return.
        :param int page_number: Filter by page number.
        :param str offset: Entry id at which to start pagination. If the ordering parameter is set to -id, the elements returned precede the identifier. Otherwise, newer elements with respect to the id are returned. 
        :param Order order: Sort responses in ascending or descending order based on the collection property set on the param ``orderBy``. If the request does not specify ``orderBy``, REST returns the collection ordered by id. 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SecretLockPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.search_secret_lock_with_http_info(**kwargs)  # noqa: E501

    def search_secret_lock_with_http_info(self, **kwargs):  # noqa: E501
        """Search secret lock entries  # noqa: E501

        Returns an array of secret locks.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_secret_lock_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Filter by address involved in the transaction.  An account's address is considered to be involved in the transaction when the account is the sender, recipient, or it is required to cosign the transaction. This filter cannot be combined with ``recipientAddress`` and ``signerPublicKey`` query params. 
        :param str secret: Filter by secret.
        :param int page_size: Select the number of entries to return.
        :param int page_number: Filter by page number.
        :param str offset: Entry id at which to start pagination. If the ordering parameter is set to -id, the elements returned precede the identifier. Otherwise, newer elements with respect to the id are returned. 
        :param Order order: Sort responses in ascending or descending order based on the collection property set on the param ``orderBy``. If the request does not specify ``orderBy``, REST returns the collection ordered by id. 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SecretLockPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'address',
            'secret',
            'page_size',
            'page_number',
            'offset',
            'order'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_secret_lock" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'page_size' in local_var_params and local_var_params['page_size'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_size` when calling `search_secret_lock`, must be a value less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'page_size' in local_var_params and local_var_params['page_size'] < 10:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_size` when calling `search_secret_lock`, must be a value greater than or equal to `10`")  # noqa: E501
        if self.api_client.client_side_validation and 'page_number' in local_var_params and local_var_params['page_number'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_number` when calling `search_secret_lock`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'address' in local_var_params and local_var_params['address'] is not None:  # noqa: E501
            query_params.append(('address', local_var_params['address']))  # noqa: E501
        if 'secret' in local_var_params and local_var_params['secret'] is not None:  # noqa: E501
            query_params.append(('secret', local_var_params['secret']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('pageSize', local_var_params['page_size']))  # noqa: E501
        if 'page_number' in local_var_params and local_var_params['page_number'] is not None:  # noqa: E501
            query_params.append(('pageNumber', local_var_params['page_number']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'order' in local_var_params and local_var_params['order'] is not None:  # noqa: E501
            query_params.append(('order', local_var_params['order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/lock/secret', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SecretLockPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


from __future__ import absolute_import

import unittest
import datetime

import symbol_openapi_client
from symbol_openapi_client.models.network_configuration_dto import NetworkConfigurationDTO  # noqa: E501
from symbol_openapi_client.rest import ApiException

class TestNetworkConfigurationDTO(unittest.TestCase):
    """NetworkConfigurationDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NetworkConfigurationDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = symbol_openapi_client.models.network_configuration_dto.NetworkConfigurationDTO()  # noqa: E501
        if include_optional :
            return NetworkConfigurationDTO(
                network = symbol_openapi_client.models.network_properties_dto.NetworkPropertiesDTO(
                    identifier = 'mijin-test', 
                    node_equality_strategy = 'host', 
                    nemesis_signer_public_key = 'AC1A6E1D8DE5B17D2C6B1293F1CAD3829EEACF38D09311BB3C8E5A880092DE26', 
                    generation_hash_seed = 'C8FC3FB54FDDFBCE0E8C71224990124E4EEC5AD5D30E592EDFA9524669A23810', 
                    epoch_adjustment = '1573430400s', ), 
                chain = symbol_openapi_client.models.chain_properties_dto.ChainPropertiesDTO(
                    enable_verifiable_state = True, 
                    enable_verifiable_receipts = True, 
                    currency_mosaic_id = '0x24F4'26B8'D549'3D4B', 
                    harvesting_mosaic_id = '0x1D9C'DC7E'218C'A88D', 
                    block_generation_target_time = '30s', 
                    block_time_smoothing_factor = '3000', 
                    block_finalization_interval = '30', 
                    importance_grouping = '39', 
                    importance_activity_percentage = '5', 
                    max_rollback_blocks = '40', 
                    max_difficulty_blocks = '60', 
                    default_dynamic_fee_multiplier = '10000', 
                    max_transaction_lifetime = '24h', 
                    max_block_future_time = '500ms', 
                    initial_currency_atomic_units = '8998999998000000', 
                    max_mosaic_atomic_units = '9000000000000000', 
                    total_chain_importance = '15000000', 
                    min_harvester_balance = '500', 
                    max_harvester_balance = '4000000', 
                    min_voter_balance = '50000', 
                    max_voting_keys_per_account = '3', 
                    min_voting_key_lifetime = '72', 
                    max_voting_key_lifetime = '26280', 
                    harvest_beneficiary_percentage = '10', 
                    harvest_network_percentage = '5', 
                    harvest_network_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                    block_prune_interval = '360', 
                    max_transactions_per_block = '200000', ), 
                plugins = symbol_openapi_client.models.plugins_properties_dto.PluginsPropertiesDTO(
                    accountlink = symbol_openapi_client.models.account_key_link_network_properties_dto.AccountKeyLinkNetworkPropertiesDTO(
                        dummy = '0', ), 
                    aggregate = symbol_openapi_client.models.aggregate_network_properties_dto.AggregateNetworkPropertiesDTO(
                        max_transactions_per_aggregate = '1000', 
                        max_cosignatures_per_aggregate = '15', 
                        enable_strict_cosignature_check = False, 
                        enable_bonded_aggregate_support = True, 
                        max_bonded_transaction_lifetime = '48h', ), 
                    lockhash = symbol_openapi_client.models.hash_lock_network_properties_dto.HashLockNetworkPropertiesDTO(
                        locked_funds_per_aggregate = '10000000', 
                        max_hash_lock_duration = '2d', ), 
                    locksecret = symbol_openapi_client.models.secret_lock_network_properties_dto.SecretLockNetworkPropertiesDTO(
                        max_secret_lock_duration = '30d', 
                        min_proof_size = '1', 
                        max_proof_size = '1000', ), 
                    metadata = symbol_openapi_client.models.metadata_network_properties_dto.MetadataNetworkPropertiesDTO(
                        max_value_size = '1024', ), 
                    mosaic = symbol_openapi_client.models.mosaic_network_properties_dto.MosaicNetworkPropertiesDTO(
                        max_mosaics_per_account = '10000', 
                        max_mosaic_duration = '3650d', 
                        max_mosaic_divisibility = '6', 
                        mosaic_rental_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                        mosaic_rental_fee = '500', ), 
                    multisig = symbol_openapi_client.models.multisig_network_properties_dto.MultisigNetworkPropertiesDTO(
                        max_multisig_depth = '3', 
                        max_cosignatories_per_account = '10', 
                        max_cosigned_accounts_per_account = '5', ), 
                    namespace = symbol_openapi_client.models.namespace_network_properties_dto.NamespaceNetworkPropertiesDTO(
                        max_name_size = '64', 
                        max_child_namespaces = '500', 
                        max_namespace_depth = '3', 
                        min_namespace_duration = '1m', 
                        max_namespace_duration = '365d', 
                        namespace_grace_period_duration = '2m', 
                        reserved_root_namespace_names = 'xem, nem, user, account, org, com, biz, net, edu, mil, gov, info', 
                        namespace_rental_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                        root_namespace_rental_fee_per_block = '1', 
                        child_namespace_rental_fee = '100', ), 
                    restrictionaccount = symbol_openapi_client.models.account_restriction_network_properties_dto.AccountRestrictionNetworkPropertiesDTO(
                        max_account_restriction_values = '512', ), 
                    restrictionmosaic = symbol_openapi_client.models.mosaic_restriction_network_properties_dto.MosaicRestrictionNetworkPropertiesDTO(
                        max_mosaic_restriction_values = '20', ), 
                    transfer = symbol_openapi_client.models.transfer_network_properties_dto.TransferNetworkPropertiesDTO(
                        max_message_size = '1024', ), )
            )
        else :
            return NetworkConfigurationDTO(
                network = symbol_openapi_client.models.network_properties_dto.NetworkPropertiesDTO(
                    identifier = 'mijin-test', 
                    node_equality_strategy = 'host', 
                    nemesis_signer_public_key = 'AC1A6E1D8DE5B17D2C6B1293F1CAD3829EEACF38D09311BB3C8E5A880092DE26', 
                    generation_hash_seed = 'C8FC3FB54FDDFBCE0E8C71224990124E4EEC5AD5D30E592EDFA9524669A23810', 
                    epoch_adjustment = '1573430400s', ),
                chain = symbol_openapi_client.models.chain_properties_dto.ChainPropertiesDTO(
                    enable_verifiable_state = True, 
                    enable_verifiable_receipts = True, 
                    currency_mosaic_id = '0x24F4'26B8'D549'3D4B', 
                    harvesting_mosaic_id = '0x1D9C'DC7E'218C'A88D', 
                    block_generation_target_time = '30s', 
                    block_time_smoothing_factor = '3000', 
                    block_finalization_interval = '30', 
                    importance_grouping = '39', 
                    importance_activity_percentage = '5', 
                    max_rollback_blocks = '40', 
                    max_difficulty_blocks = '60', 
                    default_dynamic_fee_multiplier = '10000', 
                    max_transaction_lifetime = '24h', 
                    max_block_future_time = '500ms', 
                    initial_currency_atomic_units = '8998999998000000', 
                    max_mosaic_atomic_units = '9000000000000000', 
                    total_chain_importance = '15000000', 
                    min_harvester_balance = '500', 
                    max_harvester_balance = '4000000', 
                    min_voter_balance = '50000', 
                    max_voting_keys_per_account = '3', 
                    min_voting_key_lifetime = '72', 
                    max_voting_key_lifetime = '26280', 
                    harvest_beneficiary_percentage = '10', 
                    harvest_network_percentage = '5', 
                    harvest_network_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                    block_prune_interval = '360', 
                    max_transactions_per_block = '200000', ),
                plugins = symbol_openapi_client.models.plugins_properties_dto.PluginsPropertiesDTO(
                    accountlink = symbol_openapi_client.models.account_key_link_network_properties_dto.AccountKeyLinkNetworkPropertiesDTO(
                        dummy = '0', ), 
                    aggregate = symbol_openapi_client.models.aggregate_network_properties_dto.AggregateNetworkPropertiesDTO(
                        max_transactions_per_aggregate = '1000', 
                        max_cosignatures_per_aggregate = '15', 
                        enable_strict_cosignature_check = False, 
                        enable_bonded_aggregate_support = True, 
                        max_bonded_transaction_lifetime = '48h', ), 
                    lockhash = symbol_openapi_client.models.hash_lock_network_properties_dto.HashLockNetworkPropertiesDTO(
                        locked_funds_per_aggregate = '10000000', 
                        max_hash_lock_duration = '2d', ), 
                    locksecret = symbol_openapi_client.models.secret_lock_network_properties_dto.SecretLockNetworkPropertiesDTO(
                        max_secret_lock_duration = '30d', 
                        min_proof_size = '1', 
                        max_proof_size = '1000', ), 
                    metadata = symbol_openapi_client.models.metadata_network_properties_dto.MetadataNetworkPropertiesDTO(
                        max_value_size = '1024', ), 
                    mosaic = symbol_openapi_client.models.mosaic_network_properties_dto.MosaicNetworkPropertiesDTO(
                        max_mosaics_per_account = '10000', 
                        max_mosaic_duration = '3650d', 
                        max_mosaic_divisibility = '6', 
                        mosaic_rental_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                        mosaic_rental_fee = '500', ), 
                    multisig = symbol_openapi_client.models.multisig_network_properties_dto.MultisigNetworkPropertiesDTO(
                        max_multisig_depth = '3', 
                        max_cosignatories_per_account = '10', 
                        max_cosigned_accounts_per_account = '5', ), 
                    namespace = symbol_openapi_client.models.namespace_network_properties_dto.NamespaceNetworkPropertiesDTO(
                        max_name_size = '64', 
                        max_child_namespaces = '500', 
                        max_namespace_depth = '3', 
                        min_namespace_duration = '1m', 
                        max_namespace_duration = '365d', 
                        namespace_grace_period_duration = '2m', 
                        reserved_root_namespace_names = 'xem, nem, user, account, org, com, biz, net, edu, mil, gov, info', 
                        namespace_rental_fee_sink_address = 'SAAA244WMCB2JXGNQTQHQOS45TGBFF4V2MJBVOQ', 
                        root_namespace_rental_fee_per_block = '1', 
                        child_namespace_rental_fee = '100', ), 
                    restrictionaccount = symbol_openapi_client.models.account_restriction_network_properties_dto.AccountRestrictionNetworkPropertiesDTO(
                        max_account_restriction_values = '512', ), 
                    restrictionmosaic = symbol_openapi_client.models.mosaic_restriction_network_properties_dto.MosaicRestrictionNetworkPropertiesDTO(
                        max_mosaic_restriction_values = '20', ), 
                    transfer = symbol_openapi_client.models.transfer_network_properties_dto.TransferNetworkPropertiesDTO(
                        max_message_size = '1024', ), ),
        )

    def testNetworkConfigurationDTO(self):
        """Test NetworkConfigurationDTO"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class TransactionStatusDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'group': 'TransactionGroupEnum',
        'code': 'TransactionStatusEnum',
        'hash': 'str',
        'deadline': 'str',
        'height': 'str'
    }

    attribute_map = {
        'group': 'group',
        'code': 'code',
        'hash': 'hash',
        'deadline': 'deadline',
        'height': 'height'
    }

    def __init__(self, group=None, code=None, hash=None, deadline=None, height=None, local_vars_configuration=None):  # noqa: E501
        """TransactionStatusDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._group = None
        self._code = None
        self._hash = None
        self._deadline = None
        self._height = None
        self.discriminator = None

        self.group = group
        if code is not None:
            self.code = code
        self.hash = hash
        self.deadline = deadline
        if height is not None:
            self.height = height

    @property
    def group(self):
        """Gets the group of this TransactionStatusDTO.  # noqa: E501


        :return: The group of this TransactionStatusDTO.  # noqa: E501
        :rtype: TransactionGroupEnum
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this TransactionStatusDTO.


        :param group: The group of this TransactionStatusDTO.  # noqa: E501
        :type: TransactionGroupEnum
        """
        if self.local_vars_configuration.client_side_validation and group is None:  # noqa: E501
            raise ValueError("Invalid value for `group`, must not be `None`")  # noqa: E501

        self._group = group

    @property
    def code(self):
        """Gets the code of this TransactionStatusDTO.  # noqa: E501


        :return: The code of this TransactionStatusDTO.  # noqa: E501
        :rtype: TransactionStatusEnum
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this TransactionStatusDTO.


        :param code: The code of this TransactionStatusDTO.  # noqa: E501
        :type: TransactionStatusEnum
        """

        self._code = code

    @property
    def hash(self):
        """Gets the hash of this TransactionStatusDTO.  # noqa: E501


        :return: The hash of this TransactionStatusDTO.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this TransactionStatusDTO.


        :param hash: The hash of this TransactionStatusDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and hash is None:  # noqa: E501
            raise ValueError("Invalid value for `hash`, must not be `None`")  # noqa: E501

        self._hash = hash

    @property
    def deadline(self):
        """Gets the deadline of this TransactionStatusDTO.  # noqa: E501

        Duration expressed in number of blocks.  # noqa: E501

        :return: The deadline of this TransactionStatusDTO.  # noqa: E501
        :rtype: str
        """
        return self._deadline

    @deadline.setter
    def deadline(self, deadline):
        """Sets the deadline of this TransactionStatusDTO.

        Duration expressed in number of blocks.  # noqa: E501

        :param deadline: The deadline of this TransactionStatusDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and deadline is None:  # noqa: E501
            raise ValueError("Invalid value for `deadline`, must not be `None`")  # noqa: E501

        self._deadline = deadline

    @property
    def height(self):
        """Gets the height of this TransactionStatusDTO.  # noqa: E501

        Height of the blockchain.  # noqa: E501

        :return: The height of this TransactionStatusDTO.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this TransactionStatusDTO.

        Height of the blockchain.  # noqa: E501

        :param height: The height of this TransactionStatusDTO.  # noqa: E501
        :type: str
        """

        self._height = height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionStatusDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TransactionStatusDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from symbol_openapi_client.api_client import ApiClient
from symbol_openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MultisigRoutesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_account_multisig(self, address, **kwargs):  # noqa: E501
        """Get multisig account information  # noqa: E501

        Returns the multisig account information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_multisig(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Account address. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MultisigAccountInfoDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_account_multisig_with_http_info(address, **kwargs)  # noqa: E501

    def get_account_multisig_with_http_info(self, address, **kwargs):  # noqa: E501
        """Get multisig account information  # noqa: E501

        Returns the multisig account information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_multisig_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Account address. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MultisigAccountInfoDTO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'address'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_multisig" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'address' is set
        if self.api_client.client_side_validation and ('address' not in local_var_params or  # noqa: E501
                                                        local_var_params['address'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `address` when calling `get_account_multisig`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in local_var_params:
            path_params['address'] = local_var_params['address']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/account/{address}/multisig', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MultisigAccountInfoDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_account_multisig_graph(self, address, **kwargs):  # noqa: E501
        """Get multisig account graph information  # noqa: E501

        Returns the multisig account graph.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_multisig_graph(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Account address. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MultisigAccountGraphInfoDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_account_multisig_graph_with_http_info(address, **kwargs)  # noqa: E501

    def get_account_multisig_graph_with_http_info(self, address, **kwargs):  # noqa: E501
        """Get multisig account graph information  # noqa: E501

        Returns the multisig account graph.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_multisig_graph_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Account address. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MultisigAccountGraphInfoDTO], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'address'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_multisig_graph" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'address' is set
        if self.api_client.client_side_validation and ('address' not in local_var_params or  # noqa: E501
                                                        local_var_params['address'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `address` when calling `get_account_multisig_graph`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in local_var_params:
            path_params['address'] = local_var_params['address']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/account/{address}/multisig/graph', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MultisigAccountGraphInfoDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_account_multisig_merkle(self, address, **kwargs):  # noqa: E501
        """Get multisig account merkle information  # noqa: E501

        Returns the multisig account merkle information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_multisig_merkle(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Account address. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MerkleStateInfoDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_account_multisig_merkle_with_http_info(address, **kwargs)  # noqa: E501

    def get_account_multisig_merkle_with_http_info(self, address, **kwargs):  # noqa: E501
        """Get multisig account merkle information  # noqa: E501

        Returns the multisig account merkle information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_multisig_merkle_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str address: Account address. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MerkleStateInfoDTO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'address'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_multisig_merkle" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'address' is set
        if self.api_client.client_side_validation and ('address' not in local_var_params or  # noqa: E501
                                                        local_var_params['address'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `address` when calling `get_account_multisig_merkle`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in local_var_params:
            path_params['address'] = local_var_params['address']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/account/{address}/multisig/merkle', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MerkleStateInfoDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class NodeInfoDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'int',
        'public_key': 'str',
        'network_generation_hash_seed': 'str',
        'roles': 'int',
        'port': 'int',
        'network_identifier': 'int',
        'friendly_name': 'str',
        'host': 'str',
        'node_public_key': 'str'
    }

    attribute_map = {
        'version': 'version',
        'public_key': 'publicKey',
        'network_generation_hash_seed': 'networkGenerationHashSeed',
        'roles': 'roles',
        'port': 'port',
        'network_identifier': 'networkIdentifier',
        'friendly_name': 'friendlyName',
        'host': 'host',
        'node_public_key': 'nodePublicKey'
    }

    def __init__(self, version=None, public_key=None, network_generation_hash_seed=None, roles=None, port=None, network_identifier=None, friendly_name=None, host=None, node_public_key=None, local_vars_configuration=None):  # noqa: E501
        """NodeInfoDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._public_key = None
        self._network_generation_hash_seed = None
        self._roles = None
        self._port = None
        self._network_identifier = None
        self._friendly_name = None
        self._host = None
        self._node_public_key = None
        self.discriminator = None

        self.version = version
        self.public_key = public_key
        self.network_generation_hash_seed = network_generation_hash_seed
        self.roles = roles
        self.port = port
        self.network_identifier = network_identifier
        self.friendly_name = friendly_name
        self.host = host
        if node_public_key is not None:
            self.node_public_key = node_public_key

    @property
    def version(self):
        """Gets the version of this NodeInfoDTO.  # noqa: E501

        Version of the application.  # noqa: E501

        :return: The version of this NodeInfoDTO.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this NodeInfoDTO.

        Version of the application.  # noqa: E501

        :param version: The version of this NodeInfoDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def public_key(self):
        """Gets the public_key of this NodeInfoDTO.  # noqa: E501

        Public key.  # noqa: E501

        :return: The public_key of this NodeInfoDTO.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this NodeInfoDTO.

        Public key.  # noqa: E501

        :param public_key: The public_key of this NodeInfoDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and public_key is None:  # noqa: E501
            raise ValueError("Invalid value for `public_key`, must not be `None`")  # noqa: E501

        self._public_key = public_key

    @property
    def network_generation_hash_seed(self):
        """Gets the network_generation_hash_seed of this NodeInfoDTO.  # noqa: E501


        :return: The network_generation_hash_seed of this NodeInfoDTO.  # noqa: E501
        :rtype: str
        """
        return self._network_generation_hash_seed

    @network_generation_hash_seed.setter
    def network_generation_hash_seed(self, network_generation_hash_seed):
        """Sets the network_generation_hash_seed of this NodeInfoDTO.


        :param network_generation_hash_seed: The network_generation_hash_seed of this NodeInfoDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and network_generation_hash_seed is None:  # noqa: E501
            raise ValueError("Invalid value for `network_generation_hash_seed`, must not be `None`")  # noqa: E501

        self._network_generation_hash_seed = network_generation_hash_seed

    @property
    def roles(self):
        """Gets the roles of this NodeInfoDTO.  # noqa: E501

        A number that defines the different roles the node provides. Possible roles are: * 1 - Peer node. * 2 - Api node. * 4 - Voting node. * 64 - IPv4 compatible node * 128 - IPv6 compatible node.  The values are bitwise added together, Examples: 1 = Just Peer. 2 = Just Api. 3 = Peer and Api node. 7 = Peer, Api and Voting node. 65 = IPv4 and Peer node.   # noqa: E501

        :return: The roles of this NodeInfoDTO.  # noqa: E501
        :rtype: int
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this NodeInfoDTO.

        A number that defines the different roles the node provides. Possible roles are: * 1 - Peer node. * 2 - Api node. * 4 - Voting node. * 64 - IPv4 compatible node * 128 - IPv6 compatible node.  The values are bitwise added together, Examples: 1 = Just Peer. 2 = Just Api. 3 = Peer and Api node. 7 = Peer, Api and Voting node. 65 = IPv4 and Peer node.   # noqa: E501

        :param roles: The roles of this NodeInfoDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and roles is None:  # noqa: E501
            raise ValueError("Invalid value for `roles`, must not be `None`")  # noqa: E501

        self._roles = roles

    @property
    def port(self):
        """Gets the port of this NodeInfoDTO.  # noqa: E501

        Port used for the communication.  # noqa: E501

        :return: The port of this NodeInfoDTO.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this NodeInfoDTO.

        Port used for the communication.  # noqa: E501

        :param port: The port of this NodeInfoDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def network_identifier(self):
        """Gets the network_identifier of this NodeInfoDTO.  # noqa: E501


        :return: The network_identifier of this NodeInfoDTO.  # noqa: E501
        :rtype: int
        """
        return self._network_identifier

    @network_identifier.setter
    def network_identifier(self, network_identifier):
        """Sets the network_identifier of this NodeInfoDTO.


        :param network_identifier: The network_identifier of this NodeInfoDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and network_identifier is None:  # noqa: E501
            raise ValueError("Invalid value for `network_identifier`, must not be `None`")  # noqa: E501

        self._network_identifier = network_identifier

    @property
    def friendly_name(self):
        """Gets the friendly_name of this NodeInfoDTO.  # noqa: E501

        Node friendly name.  # noqa: E501

        :return: The friendly_name of this NodeInfoDTO.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        """Sets the friendly_name of this NodeInfoDTO.

        Node friendly name.  # noqa: E501

        :param friendly_name: The friendly_name of this NodeInfoDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and friendly_name is None:  # noqa: E501
            raise ValueError("Invalid value for `friendly_name`, must not be `None`")  # noqa: E501

        self._friendly_name = friendly_name

    @property
    def host(self):
        """Gets the host of this NodeInfoDTO.  # noqa: E501

        Node IP address.  # noqa: E501

        :return: The host of this NodeInfoDTO.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this NodeInfoDTO.

        Node IP address.  # noqa: E501

        :param host: The host of this NodeInfoDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and host is None:  # noqa: E501
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def node_public_key(self):
        """Gets the node_public_key of this NodeInfoDTO.  # noqa: E501

        Public key.  # noqa: E501

        :return: The node_public_key of this NodeInfoDTO.  # noqa: E501
        :rtype: str
        """
        return self._node_public_key

    @node_public_key.setter
    def node_public_key(self, node_public_key):
        """Sets the node_public_key of this NodeInfoDTO.

        Public key.  # noqa: E501

        :param node_public_key: The node_public_key of this NodeInfoDTO.  # noqa: E501
        :type: str
        """

        self._node_public_key = node_public_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeInfoDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeInfoDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class MosaicDefinitionTransactionDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'size': 'int',
        'signature': 'str',
        'signer_public_key': 'str',
        'version': 'int',
        'network': 'NetworkTypeEnum',
        'type': 'int',
        'max_fee': 'str',
        'deadline': 'str',
        'id': 'str',
        'duration': 'str',
        'nonce': 'int',
        'flags': 'int',
        'divisibility': 'int'
    }

    attribute_map = {
        'size': 'size',
        'signature': 'signature',
        'signer_public_key': 'signerPublicKey',
        'version': 'version',
        'network': 'network',
        'type': 'type',
        'max_fee': 'maxFee',
        'deadline': 'deadline',
        'id': 'id',
        'duration': 'duration',
        'nonce': 'nonce',
        'flags': 'flags',
        'divisibility': 'divisibility'
    }

    def __init__(self, size=None, signature=None, signer_public_key=None, version=None, network=None, type=None, max_fee=None, deadline=None, id=None, duration=None, nonce=None, flags=None, divisibility=None, local_vars_configuration=None):  # noqa: E501
        """MosaicDefinitionTransactionDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._size = None
        self._signature = None
        self._signer_public_key = None
        self._version = None
        self._network = None
        self._type = None
        self._max_fee = None
        self._deadline = None
        self._id = None
        self._duration = None
        self._nonce = None
        self._flags = None
        self._divisibility = None
        self.discriminator = None

        self.size = size
        self.signature = signature
        self.signer_public_key = signer_public_key
        self.version = version
        self.network = network
        self.type = type
        self.max_fee = max_fee
        self.deadline = deadline
        self.id = id
        self.duration = duration
        self.nonce = nonce
        self.flags = flags
        self.divisibility = divisibility

    @property
    def size(self):
        """Gets the size of this MosaicDefinitionTransactionDTO.  # noqa: E501

        A number that allows uint 32 values.  # noqa: E501

        :return: The size of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this MosaicDefinitionTransactionDTO.

        A number that allows uint 32 values.  # noqa: E501

        :param size: The size of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def signature(self):
        """Gets the signature of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Entity's signature generated by the signer.  # noqa: E501

        :return: The signature of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this MosaicDefinitionTransactionDTO.

        Entity's signature generated by the signer.  # noqa: E501

        :param signature: The signature of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signature is None:  # noqa: E501
            raise ValueError("Invalid value for `signature`, must not be `None`")  # noqa: E501

        self._signature = signature

    @property
    def signer_public_key(self):
        """Gets the signer_public_key of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Public key.  # noqa: E501

        :return: The signer_public_key of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._signer_public_key

    @signer_public_key.setter
    def signer_public_key(self, signer_public_key):
        """Sets the signer_public_key of this MosaicDefinitionTransactionDTO.

        Public key.  # noqa: E501

        :param signer_public_key: The signer_public_key of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signer_public_key is None:  # noqa: E501
            raise ValueError("Invalid value for `signer_public_key`, must not be `None`")  # noqa: E501

        self._signer_public_key = signer_public_key

    @property
    def version(self):
        """Gets the version of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Entity version.  # noqa: E501

        :return: The version of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this MosaicDefinitionTransactionDTO.

        Entity version.  # noqa: E501

        :param version: The version of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def network(self):
        """Gets the network of this MosaicDefinitionTransactionDTO.  # noqa: E501


        :return: The network of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: NetworkTypeEnum
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this MosaicDefinitionTransactionDTO.


        :param network: The network of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: NetworkTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and network is None:  # noqa: E501
            raise ValueError("Invalid value for `network`, must not be `None`")  # noqa: E501

        self._network = network

    @property
    def type(self):
        """Gets the type of this MosaicDefinitionTransactionDTO.  # noqa: E501


        :return: The type of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MosaicDefinitionTransactionDTO.


        :param type: The type of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def max_fee(self):
        """Gets the max_fee of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Absolute amount. An amount of 123456789 (absolute) for a mosaic with divisibility 6 means 123.456789 (relative).  # noqa: E501

        :return: The max_fee of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_fee

    @max_fee.setter
    def max_fee(self, max_fee):
        """Sets the max_fee of this MosaicDefinitionTransactionDTO.

        Absolute amount. An amount of 123456789 (absolute) for a mosaic with divisibility 6 means 123.456789 (relative).  # noqa: E501

        :param max_fee: The max_fee of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and max_fee is None:  # noqa: E501
            raise ValueError("Invalid value for `max_fee`, must not be `None`")  # noqa: E501

        self._max_fee = max_fee

    @property
    def deadline(self):
        """Gets the deadline of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Duration expressed in number of blocks.  # noqa: E501

        :return: The deadline of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._deadline

    @deadline.setter
    def deadline(self, deadline):
        """Sets the deadline of this MosaicDefinitionTransactionDTO.

        Duration expressed in number of blocks.  # noqa: E501

        :param deadline: The deadline of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and deadline is None:  # noqa: E501
            raise ValueError("Invalid value for `deadline`, must not be `None`")  # noqa: E501

        self._deadline = deadline

    @property
    def id(self):
        """Gets the id of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Mosaic identifier.  # noqa: E501

        :return: The id of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MosaicDefinitionTransactionDTO.

        Mosaic identifier.  # noqa: E501

        :param id: The id of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def duration(self):
        """Gets the duration of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Duration expressed in number of blocks.  # noqa: E501

        :return: The duration of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this MosaicDefinitionTransactionDTO.

        Duration expressed in number of blocks.  # noqa: E501

        :param duration: The duration of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and duration is None:  # noqa: E501
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501

        self._duration = duration

    @property
    def nonce(self):
        """Gets the nonce of this MosaicDefinitionTransactionDTO.  # noqa: E501

        A number that allows uint 32 values.  # noqa: E501

        :return: The nonce of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._nonce

    @nonce.setter
    def nonce(self, nonce):
        """Sets the nonce of this MosaicDefinitionTransactionDTO.

        A number that allows uint 32 values.  # noqa: E501

        :param nonce: The nonce of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and nonce is None:  # noqa: E501
            raise ValueError("Invalid value for `nonce`, must not be `None`")  # noqa: E501

        self._nonce = nonce

    @property
    def flags(self):
        """Gets the flags of this MosaicDefinitionTransactionDTO.  # noqa: E501

        - 0x00 (none) - No flags present. - 0x01 (supplyMutable) - Mosaic supports supply changes even when mosaic owner owns partial supply. - 0x02 (transferable) - Mosaic supports transfers between arbitrary accounts. When not set, mosaic can only be transferred to and from mosaic owner. - 0x04 (restrictable) - Mosaic supports custom restrictions configured by mosaic owner.   # noqa: E501

        :return: The flags of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this MosaicDefinitionTransactionDTO.

        - 0x00 (none) - No flags present. - 0x01 (supplyMutable) - Mosaic supports supply changes even when mosaic owner owns partial supply. - 0x02 (transferable) - Mosaic supports transfers between arbitrary accounts. When not set, mosaic can only be transferred to and from mosaic owner. - 0x04 (restrictable) - Mosaic supports custom restrictions configured by mosaic owner.   # noqa: E501

        :param flags: The flags of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and flags is None:  # noqa: E501
            raise ValueError("Invalid value for `flags`, must not be `None`")  # noqa: E501

        self._flags = flags

    @property
    def divisibility(self):
        """Gets the divisibility of this MosaicDefinitionTransactionDTO.  # noqa: E501

        Determines up to what decimal place the mosaic can be divided. Divisibility of 3 means that a mosaic can be divided into smallest parts of 0.001 mosaics. The divisibility must be in the range of 0 and 6.   # noqa: E501

        :return: The divisibility of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._divisibility

    @divisibility.setter
    def divisibility(self, divisibility):
        """Sets the divisibility of this MosaicDefinitionTransactionDTO.

        Determines up to what decimal place the mosaic can be divided. Divisibility of 3 means that a mosaic can be divided into smallest parts of 0.001 mosaics. The divisibility must be in the range of 0 and 6.   # noqa: E501

        :param divisibility: The divisibility of this MosaicDefinitionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and divisibility is None:  # noqa: E501
            raise ValueError("Invalid value for `divisibility`, must not be `None`")  # noqa: E501

        self._divisibility = divisibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MosaicDefinitionTransactionDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MosaicDefinitionTransactionDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class EmbeddedMosaicGlobalRestrictionTransactionDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'signer_public_key': 'str',
        'version': 'int',
        'network': 'NetworkTypeEnum',
        'type': 'int',
        'mosaic_id': 'str',
        'reference_mosaic_id': 'str',
        'restriction_key': 'str',
        'previous_restriction_value': 'str',
        'new_restriction_value': 'str',
        'previous_restriction_type': 'MosaicRestrictionTypeEnum',
        'new_restriction_type': 'MosaicRestrictionTypeEnum'
    }

    attribute_map = {
        'signer_public_key': 'signerPublicKey',
        'version': 'version',
        'network': 'network',
        'type': 'type',
        'mosaic_id': 'mosaicId',
        'reference_mosaic_id': 'referenceMosaicId',
        'restriction_key': 'restrictionKey',
        'previous_restriction_value': 'previousRestrictionValue',
        'new_restriction_value': 'newRestrictionValue',
        'previous_restriction_type': 'previousRestrictionType',
        'new_restriction_type': 'newRestrictionType'
    }

    def __init__(self, signer_public_key=None, version=None, network=None, type=None, mosaic_id=None, reference_mosaic_id=None, restriction_key=None, previous_restriction_value=None, new_restriction_value=None, previous_restriction_type=None, new_restriction_type=None, local_vars_configuration=None):  # noqa: E501
        """EmbeddedMosaicGlobalRestrictionTransactionDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._signer_public_key = None
        self._version = None
        self._network = None
        self._type = None
        self._mosaic_id = None
        self._reference_mosaic_id = None
        self._restriction_key = None
        self._previous_restriction_value = None
        self._new_restriction_value = None
        self._previous_restriction_type = None
        self._new_restriction_type = None
        self.discriminator = None

        self.signer_public_key = signer_public_key
        self.version = version
        self.network = network
        self.type = type
        self.mosaic_id = mosaic_id
        self.reference_mosaic_id = reference_mosaic_id
        self.restriction_key = restriction_key
        self.previous_restriction_value = previous_restriction_value
        self.new_restriction_value = new_restriction_value
        self.previous_restriction_type = previous_restriction_type
        self.new_restriction_type = new_restriction_type

    @property
    def signer_public_key(self):
        """Gets the signer_public_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501

        Public key.  # noqa: E501

        :return: The signer_public_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._signer_public_key

    @signer_public_key.setter
    def signer_public_key(self, signer_public_key):
        """Sets the signer_public_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.

        Public key.  # noqa: E501

        :param signer_public_key: The signer_public_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signer_public_key is None:  # noqa: E501
            raise ValueError("Invalid value for `signer_public_key`, must not be `None`")  # noqa: E501

        self._signer_public_key = signer_public_key

    @property
    def version(self):
        """Gets the version of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501

        Entity version.  # noqa: E501

        :return: The version of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this EmbeddedMosaicGlobalRestrictionTransactionDTO.

        Entity version.  # noqa: E501

        :param version: The version of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def network(self):
        """Gets the network of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501


        :return: The network of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: NetworkTypeEnum
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this EmbeddedMosaicGlobalRestrictionTransactionDTO.


        :param network: The network of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: NetworkTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and network is None:  # noqa: E501
            raise ValueError("Invalid value for `network`, must not be `None`")  # noqa: E501

        self._network = network

    @property
    def type(self):
        """Gets the type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501


        :return: The type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.


        :param type: The type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def mosaic_id(self):
        """Gets the mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501

        Mosaic identifier. If the most significant bit of byte 0 is set, a namespaceId (alias) is used instead of the real mosaic identifier.   # noqa: E501

        :return: The mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._mosaic_id

    @mosaic_id.setter
    def mosaic_id(self, mosaic_id):
        """Sets the mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.

        Mosaic identifier. If the most significant bit of byte 0 is set, a namespaceId (alias) is used instead of the real mosaic identifier.   # noqa: E501

        :param mosaic_id: The mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and mosaic_id is None:  # noqa: E501
            raise ValueError("Invalid value for `mosaic_id`, must not be `None`")  # noqa: E501

        self._mosaic_id = mosaic_id

    @property
    def reference_mosaic_id(self):
        """Gets the reference_mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501

        Mosaic identifier. If the most significant bit of byte 0 is set, a namespaceId (alias) is used instead of the real mosaic identifier.   # noqa: E501

        :return: The reference_mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._reference_mosaic_id

    @reference_mosaic_id.setter
    def reference_mosaic_id(self, reference_mosaic_id):
        """Sets the reference_mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.

        Mosaic identifier. If the most significant bit of byte 0 is set, a namespaceId (alias) is used instead of the real mosaic identifier.   # noqa: E501

        :param reference_mosaic_id: The reference_mosaic_id of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and reference_mosaic_id is None:  # noqa: E501
            raise ValueError("Invalid value for `reference_mosaic_id`, must not be `None`")  # noqa: E501

        self._reference_mosaic_id = reference_mosaic_id

    @property
    def restriction_key(self):
        """Gets the restriction_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501

        Restriction key.  # noqa: E501

        :return: The restriction_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._restriction_key

    @restriction_key.setter
    def restriction_key(self, restriction_key):
        """Sets the restriction_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.

        Restriction key.  # noqa: E501

        :param restriction_key: The restriction_key of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and restriction_key is None:  # noqa: E501
            raise ValueError("Invalid value for `restriction_key`, must not be `None`")  # noqa: E501

        self._restriction_key = restriction_key

    @property
    def previous_restriction_value(self):
        """Gets the previous_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501

        Restriction value.  # noqa: E501

        :return: The previous_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._previous_restriction_value

    @previous_restriction_value.setter
    def previous_restriction_value(self, previous_restriction_value):
        """Sets the previous_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.

        Restriction value.  # noqa: E501

        :param previous_restriction_value: The previous_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and previous_restriction_value is None:  # noqa: E501
            raise ValueError("Invalid value for `previous_restriction_value`, must not be `None`")  # noqa: E501

        self._previous_restriction_value = previous_restriction_value

    @property
    def new_restriction_value(self):
        """Gets the new_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501

        Restriction value.  # noqa: E501

        :return: The new_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: str
        """
        return self._new_restriction_value

    @new_restriction_value.setter
    def new_restriction_value(self, new_restriction_value):
        """Sets the new_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.

        Restriction value.  # noqa: E501

        :param new_restriction_value: The new_restriction_value of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and new_restriction_value is None:  # noqa: E501
            raise ValueError("Invalid value for `new_restriction_value`, must not be `None`")  # noqa: E501

        self._new_restriction_value = new_restriction_value

    @property
    def previous_restriction_type(self):
        """Gets the previous_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501


        :return: The previous_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: MosaicRestrictionTypeEnum
        """
        return self._previous_restriction_type

    @previous_restriction_type.setter
    def previous_restriction_type(self, previous_restriction_type):
        """Sets the previous_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.


        :param previous_restriction_type: The previous_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: MosaicRestrictionTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and previous_restriction_type is None:  # noqa: E501
            raise ValueError("Invalid value for `previous_restriction_type`, must not be `None`")  # noqa: E501

        self._previous_restriction_type = previous_restriction_type

    @property
    def new_restriction_type(self):
        """Gets the new_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501


        :return: The new_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :rtype: MosaicRestrictionTypeEnum
        """
        return self._new_restriction_type

    @new_restriction_type.setter
    def new_restriction_type(self, new_restriction_type):
        """Sets the new_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.


        :param new_restriction_type: The new_restriction_type of this EmbeddedMosaicGlobalRestrictionTransactionDTO.  # noqa: E501
        :type: MosaicRestrictionTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and new_restriction_type is None:  # noqa: E501
            raise ValueError("Invalid value for `new_restriction_type`, must not be `None`")  # noqa: E501

        self._new_restriction_type = new_restriction_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmbeddedMosaicGlobalRestrictionTransactionDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmbeddedMosaicGlobalRestrictionTransactionDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class PluginsPropertiesDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'accountlink': 'AccountKeyLinkNetworkPropertiesDTO',
        'aggregate': 'AggregateNetworkPropertiesDTO',
        'lockhash': 'HashLockNetworkPropertiesDTO',
        'locksecret': 'SecretLockNetworkPropertiesDTO',
        'metadata': 'MetadataNetworkPropertiesDTO',
        'mosaic': 'MosaicNetworkPropertiesDTO',
        'multisig': 'MultisigNetworkPropertiesDTO',
        'namespace': 'NamespaceNetworkPropertiesDTO',
        'restrictionaccount': 'AccountRestrictionNetworkPropertiesDTO',
        'restrictionmosaic': 'MosaicRestrictionNetworkPropertiesDTO',
        'transfer': 'TransferNetworkPropertiesDTO'
    }

    attribute_map = {
        'accountlink': 'accountlink',
        'aggregate': 'aggregate',
        'lockhash': 'lockhash',
        'locksecret': 'locksecret',
        'metadata': 'metadata',
        'mosaic': 'mosaic',
        'multisig': 'multisig',
        'namespace': 'namespace',
        'restrictionaccount': 'restrictionaccount',
        'restrictionmosaic': 'restrictionmosaic',
        'transfer': 'transfer'
    }

    def __init__(self, accountlink=None, aggregate=None, lockhash=None, locksecret=None, metadata=None, mosaic=None, multisig=None, namespace=None, restrictionaccount=None, restrictionmosaic=None, transfer=None, local_vars_configuration=None):  # noqa: E501
        """PluginsPropertiesDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._accountlink = None
        self._aggregate = None
        self._lockhash = None
        self._locksecret = None
        self._metadata = None
        self._mosaic = None
        self._multisig = None
        self._namespace = None
        self._restrictionaccount = None
        self._restrictionmosaic = None
        self._transfer = None
        self.discriminator = None

        if accountlink is not None:
            self.accountlink = accountlink
        if aggregate is not None:
            self.aggregate = aggregate
        if lockhash is not None:
            self.lockhash = lockhash
        if locksecret is not None:
            self.locksecret = locksecret
        if metadata is not None:
            self.metadata = metadata
        if mosaic is not None:
            self.mosaic = mosaic
        if multisig is not None:
            self.multisig = multisig
        if namespace is not None:
            self.namespace = namespace
        if restrictionaccount is not None:
            self.restrictionaccount = restrictionaccount
        if restrictionmosaic is not None:
            self.restrictionmosaic = restrictionmosaic
        if transfer is not None:
            self.transfer = transfer

    @property
    def accountlink(self):
        """Gets the accountlink of this PluginsPropertiesDTO.  # noqa: E501


        :return: The accountlink of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: AccountKeyLinkNetworkPropertiesDTO
        """
        return self._accountlink

    @accountlink.setter
    def accountlink(self, accountlink):
        """Sets the accountlink of this PluginsPropertiesDTO.


        :param accountlink: The accountlink of this PluginsPropertiesDTO.  # noqa: E501
        :type: AccountKeyLinkNetworkPropertiesDTO
        """

        self._accountlink = accountlink

    @property
    def aggregate(self):
        """Gets the aggregate of this PluginsPropertiesDTO.  # noqa: E501


        :return: The aggregate of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: AggregateNetworkPropertiesDTO
        """
        return self._aggregate

    @aggregate.setter
    def aggregate(self, aggregate):
        """Sets the aggregate of this PluginsPropertiesDTO.


        :param aggregate: The aggregate of this PluginsPropertiesDTO.  # noqa: E501
        :type: AggregateNetworkPropertiesDTO
        """

        self._aggregate = aggregate

    @property
    def lockhash(self):
        """Gets the lockhash of this PluginsPropertiesDTO.  # noqa: E501


        :return: The lockhash of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: HashLockNetworkPropertiesDTO
        """
        return self._lockhash

    @lockhash.setter
    def lockhash(self, lockhash):
        """Sets the lockhash of this PluginsPropertiesDTO.


        :param lockhash: The lockhash of this PluginsPropertiesDTO.  # noqa: E501
        :type: HashLockNetworkPropertiesDTO
        """

        self._lockhash = lockhash

    @property
    def locksecret(self):
        """Gets the locksecret of this PluginsPropertiesDTO.  # noqa: E501


        :return: The locksecret of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: SecretLockNetworkPropertiesDTO
        """
        return self._locksecret

    @locksecret.setter
    def locksecret(self, locksecret):
        """Sets the locksecret of this PluginsPropertiesDTO.


        :param locksecret: The locksecret of this PluginsPropertiesDTO.  # noqa: E501
        :type: SecretLockNetworkPropertiesDTO
        """

        self._locksecret = locksecret

    @property
    def metadata(self):
        """Gets the metadata of this PluginsPropertiesDTO.  # noqa: E501


        :return: The metadata of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: MetadataNetworkPropertiesDTO
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PluginsPropertiesDTO.


        :param metadata: The metadata of this PluginsPropertiesDTO.  # noqa: E501
        :type: MetadataNetworkPropertiesDTO
        """

        self._metadata = metadata

    @property
    def mosaic(self):
        """Gets the mosaic of this PluginsPropertiesDTO.  # noqa: E501


        :return: The mosaic of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: MosaicNetworkPropertiesDTO
        """
        return self._mosaic

    @mosaic.setter
    def mosaic(self, mosaic):
        """Sets the mosaic of this PluginsPropertiesDTO.


        :param mosaic: The mosaic of this PluginsPropertiesDTO.  # noqa: E501
        :type: MosaicNetworkPropertiesDTO
        """

        self._mosaic = mosaic

    @property
    def multisig(self):
        """Gets the multisig of this PluginsPropertiesDTO.  # noqa: E501


        :return: The multisig of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: MultisigNetworkPropertiesDTO
        """
        return self._multisig

    @multisig.setter
    def multisig(self, multisig):
        """Sets the multisig of this PluginsPropertiesDTO.


        :param multisig: The multisig of this PluginsPropertiesDTO.  # noqa: E501
        :type: MultisigNetworkPropertiesDTO
        """

        self._multisig = multisig

    @property
    def namespace(self):
        """Gets the namespace of this PluginsPropertiesDTO.  # noqa: E501


        :return: The namespace of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: NamespaceNetworkPropertiesDTO
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this PluginsPropertiesDTO.


        :param namespace: The namespace of this PluginsPropertiesDTO.  # noqa: E501
        :type: NamespaceNetworkPropertiesDTO
        """

        self._namespace = namespace

    @property
    def restrictionaccount(self):
        """Gets the restrictionaccount of this PluginsPropertiesDTO.  # noqa: E501


        :return: The restrictionaccount of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: AccountRestrictionNetworkPropertiesDTO
        """
        return self._restrictionaccount

    @restrictionaccount.setter
    def restrictionaccount(self, restrictionaccount):
        """Sets the restrictionaccount of this PluginsPropertiesDTO.


        :param restrictionaccount: The restrictionaccount of this PluginsPropertiesDTO.  # noqa: E501
        :type: AccountRestrictionNetworkPropertiesDTO
        """

        self._restrictionaccount = restrictionaccount

    @property
    def restrictionmosaic(self):
        """Gets the restrictionmosaic of this PluginsPropertiesDTO.  # noqa: E501


        :return: The restrictionmosaic of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: MosaicRestrictionNetworkPropertiesDTO
        """
        return self._restrictionmosaic

    @restrictionmosaic.setter
    def restrictionmosaic(self, restrictionmosaic):
        """Sets the restrictionmosaic of this PluginsPropertiesDTO.


        :param restrictionmosaic: The restrictionmosaic of this PluginsPropertiesDTO.  # noqa: E501
        :type: MosaicRestrictionNetworkPropertiesDTO
        """

        self._restrictionmosaic = restrictionmosaic

    @property
    def transfer(self):
        """Gets the transfer of this PluginsPropertiesDTO.  # noqa: E501


        :return: The transfer of this PluginsPropertiesDTO.  # noqa: E501
        :rtype: TransferNetworkPropertiesDTO
        """
        return self._transfer

    @transfer.setter
    def transfer(self, transfer):
        """Sets the transfer of this PluginsPropertiesDTO.


        :param transfer: The transfer of this PluginsPropertiesDTO.  # noqa: E501
        :type: TransferNetworkPropertiesDTO
        """

        self._transfer = transfer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PluginsPropertiesDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PluginsPropertiesDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class AccountDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'int',
        'address': 'str',
        'address_height': 'str',
        'public_key': 'str',
        'public_key_height': 'str',
        'account_type': 'AccountTypeEnum',
        'supplemental_public_keys': 'SupplementalPublicKeysDTO',
        'activity_buckets': 'list[ActivityBucketDTO]',
        'mosaics': 'list[Mosaic]',
        'importance': 'str',
        'importance_height': 'str'
    }

    attribute_map = {
        'version': 'version',
        'address': 'address',
        'address_height': 'addressHeight',
        'public_key': 'publicKey',
        'public_key_height': 'publicKeyHeight',
        'account_type': 'accountType',
        'supplemental_public_keys': 'supplementalPublicKeys',
        'activity_buckets': 'activityBuckets',
        'mosaics': 'mosaics',
        'importance': 'importance',
        'importance_height': 'importanceHeight'
    }

    def __init__(self, version=None, address=None, address_height=None, public_key=None, public_key_height=None, account_type=None, supplemental_public_keys=None, activity_buckets=None, mosaics=None, importance=None, importance_height=None, local_vars_configuration=None):  # noqa: E501
        """AccountDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._address = None
        self._address_height = None
        self._public_key = None
        self._public_key_height = None
        self._account_type = None
        self._supplemental_public_keys = None
        self._activity_buckets = None
        self._mosaics = None
        self._importance = None
        self._importance_height = None
        self.discriminator = None

        self.version = version
        self.address = address
        self.address_height = address_height
        self.public_key = public_key
        self.public_key_height = public_key_height
        self.account_type = account_type
        self.supplemental_public_keys = supplemental_public_keys
        self.activity_buckets = activity_buckets
        self.mosaics = mosaics
        self.importance = importance
        self.importance_height = importance_height

    @property
    def version(self):
        """Gets the version of this AccountDTO.  # noqa: E501

        The version of the state  # noqa: E501

        :return: The version of this AccountDTO.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this AccountDTO.

        The version of the state  # noqa: E501

        :param version: The version of this AccountDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def address(self):
        """Gets the address of this AccountDTO.  # noqa: E501

        Address expressed in hexadecimal base.  # noqa: E501

        :return: The address of this AccountDTO.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this AccountDTO.

        Address expressed in hexadecimal base.  # noqa: E501

        :param address: The address of this AccountDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address is None:  # noqa: E501
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def address_height(self):
        """Gets the address_height of this AccountDTO.  # noqa: E501

        Height of the blockchain.  # noqa: E501

        :return: The address_height of this AccountDTO.  # noqa: E501
        :rtype: str
        """
        return self._address_height

    @address_height.setter
    def address_height(self, address_height):
        """Sets the address_height of this AccountDTO.

        Height of the blockchain.  # noqa: E501

        :param address_height: The address_height of this AccountDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address_height is None:  # noqa: E501
            raise ValueError("Invalid value for `address_height`, must not be `None`")  # noqa: E501

        self._address_height = address_height

    @property
    def public_key(self):
        """Gets the public_key of this AccountDTO.  # noqa: E501

        Public key.  # noqa: E501

        :return: The public_key of this AccountDTO.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this AccountDTO.

        Public key.  # noqa: E501

        :param public_key: The public_key of this AccountDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and public_key is None:  # noqa: E501
            raise ValueError("Invalid value for `public_key`, must not be `None`")  # noqa: E501

        self._public_key = public_key

    @property
    def public_key_height(self):
        """Gets the public_key_height of this AccountDTO.  # noqa: E501

        Height of the blockchain.  # noqa: E501

        :return: The public_key_height of this AccountDTO.  # noqa: E501
        :rtype: str
        """
        return self._public_key_height

    @public_key_height.setter
    def public_key_height(self, public_key_height):
        """Sets the public_key_height of this AccountDTO.

        Height of the blockchain.  # noqa: E501

        :param public_key_height: The public_key_height of this AccountDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and public_key_height is None:  # noqa: E501
            raise ValueError("Invalid value for `public_key_height`, must not be `None`")  # noqa: E501

        self._public_key_height = public_key_height

    @property
    def account_type(self):
        """Gets the account_type of this AccountDTO.  # noqa: E501


        :return: The account_type of this AccountDTO.  # noqa: E501
        :rtype: AccountTypeEnum
        """
        return self._account_type

    @account_type.setter
    def account_type(self, account_type):
        """Sets the account_type of this AccountDTO.


        :param account_type: The account_type of this AccountDTO.  # noqa: E501
        :type: AccountTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and account_type is None:  # noqa: E501
            raise ValueError("Invalid value for `account_type`, must not be `None`")  # noqa: E501

        self._account_type = account_type

    @property
    def supplemental_public_keys(self):
        """Gets the supplemental_public_keys of this AccountDTO.  # noqa: E501


        :return: The supplemental_public_keys of this AccountDTO.  # noqa: E501
        :rtype: SupplementalPublicKeysDTO
        """
        return self._supplemental_public_keys

    @supplemental_public_keys.setter
    def supplemental_public_keys(self, supplemental_public_keys):
        """Sets the supplemental_public_keys of this AccountDTO.


        :param supplemental_public_keys: The supplemental_public_keys of this AccountDTO.  # noqa: E501
        :type: SupplementalPublicKeysDTO
        """
        if self.local_vars_configuration.client_side_validation and supplemental_public_keys is None:  # noqa: E501
            raise ValueError("Invalid value for `supplemental_public_keys`, must not be `None`")  # noqa: E501

        self._supplemental_public_keys = supplemental_public_keys

    @property
    def activity_buckets(self):
        """Gets the activity_buckets of this AccountDTO.  # noqa: E501


        :return: The activity_buckets of this AccountDTO.  # noqa: E501
        :rtype: list[ActivityBucketDTO]
        """
        return self._activity_buckets

    @activity_buckets.setter
    def activity_buckets(self, activity_buckets):
        """Sets the activity_buckets of this AccountDTO.


        :param activity_buckets: The activity_buckets of this AccountDTO.  # noqa: E501
        :type: list[ActivityBucketDTO]
        """
        if self.local_vars_configuration.client_side_validation and activity_buckets is None:  # noqa: E501
            raise ValueError("Invalid value for `activity_buckets`, must not be `None`")  # noqa: E501

        self._activity_buckets = activity_buckets

    @property
    def mosaics(self):
        """Gets the mosaics of this AccountDTO.  # noqa: E501

        Mosaic units owned.  # noqa: E501

        :return: The mosaics of this AccountDTO.  # noqa: E501
        :rtype: list[Mosaic]
        """
        return self._mosaics

    @mosaics.setter
    def mosaics(self, mosaics):
        """Sets the mosaics of this AccountDTO.

        Mosaic units owned.  # noqa: E501

        :param mosaics: The mosaics of this AccountDTO.  # noqa: E501
        :type: list[Mosaic]
        """
        if self.local_vars_configuration.client_side_validation and mosaics is None:  # noqa: E501
            raise ValueError("Invalid value for `mosaics`, must not be `None`")  # noqa: E501

        self._mosaics = mosaics

    @property
    def importance(self):
        """Gets the importance of this AccountDTO.  # noqa: E501

        Probability of an account to harvest the next block.  # noqa: E501

        :return: The importance of this AccountDTO.  # noqa: E501
        :rtype: str
        """
        return self._importance

    @importance.setter
    def importance(self, importance):
        """Sets the importance of this AccountDTO.

        Probability of an account to harvest the next block.  # noqa: E501

        :param importance: The importance of this AccountDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and importance is None:  # noqa: E501
            raise ValueError("Invalid value for `importance`, must not be `None`")  # noqa: E501

        self._importance = importance

    @property
    def importance_height(self):
        """Gets the importance_height of this AccountDTO.  # noqa: E501

        Height of the blockchain.  # noqa: E501

        :return: The importance_height of this AccountDTO.  # noqa: E501
        :rtype: str
        """
        return self._importance_height

    @importance_height.setter
    def importance_height(self, importance_height):
        """Sets the importance_height of this AccountDTO.

        Height of the blockchain.  # noqa: E501

        :param importance_height: The importance_height of this AccountDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and importance_height is None:  # noqa: E501
            raise ValueError("Invalid value for `importance_height`, must not be `None`")  # noqa: E501

        self._importance_height = importance_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class MerkleTreeBranchDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'MerkleTreeNodeTypeEnum',
        'path': 'str',
        'encoded_path': 'str',
        'nibble_count': 'int',
        'link_mask': 'str',
        'links': 'list[MerkleTreeBranchLinkDTO]',
        'branch_hash': 'str'
    }

    attribute_map = {
        'type': 'type',
        'path': 'path',
        'encoded_path': 'encodedPath',
        'nibble_count': 'nibbleCount',
        'link_mask': 'linkMask',
        'links': 'links',
        'branch_hash': 'branchHash'
    }

    def __init__(self, type=None, path=None, encoded_path=None, nibble_count=None, link_mask=None, links=None, branch_hash=None, local_vars_configuration=None):  # noqa: E501
        """MerkleTreeBranchDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._path = None
        self._encoded_path = None
        self._nibble_count = None
        self._link_mask = None
        self._links = None
        self._branch_hash = None
        self.discriminator = None

        self.type = type
        self.path = path
        self.encoded_path = encoded_path
        self.nibble_count = nibble_count
        self.link_mask = link_mask
        self.links = links
        self.branch_hash = branch_hash

    @property
    def type(self):
        """Gets the type of this MerkleTreeBranchDTO.  # noqa: E501


        :return: The type of this MerkleTreeBranchDTO.  # noqa: E501
        :rtype: MerkleTreeNodeTypeEnum
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MerkleTreeBranchDTO.


        :param type: The type of this MerkleTreeBranchDTO.  # noqa: E501
        :type: MerkleTreeNodeTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def path(self):
        """Gets the path of this MerkleTreeBranchDTO.  # noqa: E501

        Branch link path.  # noqa: E501

        :return: The path of this MerkleTreeBranchDTO.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this MerkleTreeBranchDTO.

        Branch link path.  # noqa: E501

        :param path: The path of this MerkleTreeBranchDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def encoded_path(self):
        """Gets the encoded_path of this MerkleTreeBranchDTO.  # noqa: E501

        Encoded branch link path.  # noqa: E501

        :return: The encoded_path of this MerkleTreeBranchDTO.  # noqa: E501
        :rtype: str
        """
        return self._encoded_path

    @encoded_path.setter
    def encoded_path(self, encoded_path):
        """Sets the encoded_path of this MerkleTreeBranchDTO.

        Encoded branch link path.  # noqa: E501

        :param encoded_path: The encoded_path of this MerkleTreeBranchDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and encoded_path is None:  # noqa: E501
            raise ValueError("Invalid value for `encoded_path`, must not be `None`")  # noqa: E501

        self._encoded_path = encoded_path

    @property
    def nibble_count(self):
        """Gets the nibble_count of this MerkleTreeBranchDTO.  # noqa: E501

        Nibble count.  # noqa: E501

        :return: The nibble_count of this MerkleTreeBranchDTO.  # noqa: E501
        :rtype: int
        """
        return self._nibble_count

    @nibble_count.setter
    def nibble_count(self, nibble_count):
        """Sets the nibble_count of this MerkleTreeBranchDTO.

        Nibble count.  # noqa: E501

        :param nibble_count: The nibble_count of this MerkleTreeBranchDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and nibble_count is None:  # noqa: E501
            raise ValueError("Invalid value for `nibble_count`, must not be `None`")  # noqa: E501

        self._nibble_count = nibble_count

    @property
    def link_mask(self):
        """Gets the link_mask of this MerkleTreeBranchDTO.  # noqa: E501

        Branch link bitmask.  # noqa: E501

        :return: The link_mask of this MerkleTreeBranchDTO.  # noqa: E501
        :rtype: str
        """
        return self._link_mask

    @link_mask.setter
    def link_mask(self, link_mask):
        """Sets the link_mask of this MerkleTreeBranchDTO.

        Branch link bitmask.  # noqa: E501

        :param link_mask: The link_mask of this MerkleTreeBranchDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and link_mask is None:  # noqa: E501
            raise ValueError("Invalid value for `link_mask`, must not be `None`")  # noqa: E501

        self._link_mask = link_mask

    @property
    def links(self):
        """Gets the links of this MerkleTreeBranchDTO.  # noqa: E501

        Branch links (max 16).  # noqa: E501

        :return: The links of this MerkleTreeBranchDTO.  # noqa: E501
        :rtype: list[MerkleTreeBranchLinkDTO]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this MerkleTreeBranchDTO.

        Branch links (max 16).  # noqa: E501

        :param links: The links of this MerkleTreeBranchDTO.  # noqa: E501
        :type: list[MerkleTreeBranchLinkDTO]
        """
        if self.local_vars_configuration.client_side_validation and links is None:  # noqa: E501
            raise ValueError("Invalid value for `links`, must not be `None`")  # noqa: E501

        self._links = links

    @property
    def branch_hash(self):
        """Gets the branch_hash of this MerkleTreeBranchDTO.  # noqa: E501


        :return: The branch_hash of this MerkleTreeBranchDTO.  # noqa: E501
        :rtype: str
        """
        return self._branch_hash

    @branch_hash.setter
    def branch_hash(self, branch_hash):
        """Sets the branch_hash of this MerkleTreeBranchDTO.


        :param branch_hash: The branch_hash of this MerkleTreeBranchDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and branch_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `branch_hash`, must not be `None`")  # noqa: E501

        self._branch_hash = branch_hash

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MerkleTreeBranchDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MerkleTreeBranchDTO):
            return True

        return self.to_dict() != other.to_dict()
